%global _disable_ld_no_undefined 1

%define oname   VirtualGL
%define libname %mklibname %{name}

Name:           virtualgl
Summary:        A toolkit for displaying OpenGL applications to thin clients
Group:          Networking/Other
Version:        2.5.1
Release:        %mkrel 1
URL:            http://www.virtualgl.org
License:        wxWindows
Source0:        http://downloads.sourceforge.net/virtualgl/%{oname}-%{version}.tar.gz
Patch1:         virtualgl-2.3.3-deb-remove-glxinfo.patch
# fix for rhbz#923961 - Wrong VGL_BINDIR path in script /usr/bin/vglconnect
Patch2:         VirtualGL-redhatpathsfix.patch
# fix for rhbz#1088475 - Don't install hidden files into /usr/bin
Patch3:         virtualgl-2.4.1-mga-libexec-paths.patch
Patch4:		virtualgl-2.4.1-mga-cmake-fixes.patch
BuildRequires:  cmake
BuildRequires:  fltk-devel
BuildRequires:  jpeg-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xv)

%description
VirtualGL is a library which allows most Linux OpenGL applications to be
remotely displayed to a thin client without the need to alter the
applications in any way.  VGL inserts itself into an application at run time
and intercepts a handful of GLX calls, which it reroutes to the server's
display (which presumably has a 3D accelerator attached.)  This causes all
3D rendering to occur on the server's display.  As each frame is rendered
by the server, VirtualGL reads back the pixels from the server's framebuffer
and sends them to the client for re-compositing into the appropriate X
Window.

VirtualGL can be used to give hardware-accelerated 3D capabilities to
VNC or other remote display environments that lack GLX support.  In a LAN
environment, it can also be used with its built-in motion-JPEG video delivery
system to remotely display full-screen 3D applications at 20+ frames/second.

%files
%doc %{_docdir}/%{name}/
%{_bindir}/*
%{_libexecdir}/vglrun.vars%{__isa_bits}

#--------------------------------------------------------------------
%package -n %{libname}
Summary:        Libraries injected by VirtualGL into applications that are ran through it
Group:          System/Libraries

%description -n %{libname}
Libraries injected by VirtualGL into applications that are ran throught it.
Lib package allow installing 32 and 64 bits libraries at the same time.

%files -n %{libname}
%{_libdir}/libdlfaker.so
%{_libdir}/libgefaker.so
%{_libdir}/libvglfaker.so
%{_libdir}/libvglfaker-nodl.so

#--------------------------------------------------------------------
%package devel
Summary:        A toolkit for displaying OpenGL applications to thin clients
Group:          Networking/Other
Requires:       %{libname} = %{version}-%{release}

%description devel
Development headers for VirtualGL.

%files devel
%{_includedir}/rrtransport.h
%{_includedir}/rr.h

#--------------------------------------------------------------------
%prep
%setup -q -n %{oname}-%{version}
%autopatch -p1

%build
%cmake \
    -DVGL_BUILDSTATIC=0 \
    -DVGL_SYSTEMFLTK=1 \
    -DVGL_SYSTEMGLX=1 \
    -DVGL_DOCDIR=%{_docdir}/%{name} \
    -DVGL_LIBDIR=%{_libdir} \
    -DTJPEG_INCLUDE_DIR=%{_includedir} \
    -DTJPEG_LIBRARY=%{_libdir}/libturbojpeg.so

%make_build

%install
%make_install -C build

install -d %{buildroot}%{_libexecdir}
mv %{buildroot}%{_bindir}/.vglrun.vars%{__isa_bits} %{buildroot}%{_libexecdir}/vglrun.vars%{__isa_bits}


%changelog
* Sat Oct 29 2016 akien <akien> 2.5.1-1.mga6
+ Revision: 1064038
- Version 2.5.1

* Sat Apr 23 2016 akien <akien> 2.5-1.mga6
+ Revision: 1005680
- Version 2.5
- Set _disable_ld_no_undefined, I give up on this broken piece of underlinked code

* Fri Feb 12 2016 umeabot <umeabot> 2.4.1-10.mga6
+ Revision: 959142
- Mageia 6 Mass Rebuild

* Thu Aug 20 2015 fwang <fwang> 2.4.1-9.mga6
+ Revision: 866671
- try using find_package rather than plain include
- rebuild for new fltk

* Sun Jun 21 2015 akien <akien> 2.4.1-1.mga6
+ Revision: 837264
- Version 2.4.1
- Build against system fltk and glx
- Move and dehide hidden binaries from /usr/bin to /usr/libexec (rhbz#1088475)
- Fix wrong VGL_BINDIR path in /usr/bin/vglconnect (rhbz#923961)

* Wed Oct 15 2014 umeabot <umeabot> 2.3.3-5.mga5
+ Revision: 745367
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.3.3-4.mga5
+ Revision: 690217
- Mageia 5 Mass Rebuild

  + akien <akien>
    - Use VGL_FAKELIBDIR instead of manual fix
    - Add Debian patch to remove glxinfo (the one in mesa is newer)

* Thu Feb 06 2014 akien <akien> 2.3.3-2.mga5
+ Revision: 584712
- Use %%__isa_bits to make the .vglrun.vars[32,64] binary arch-dependent
- Removing /usr/bin/.vglrun.vars64 from i586 files list
- New version 2.3.3: http://svn.code.sf.net/p/virtualgl/code/vgl/trunk/ChangeLog.txt

* Sat Oct 19 2013 umeabot <umeabot> 2.3.2-4.mga4
+ Revision: 524170
- Mageia 4 Mass Rebuild

* Wed May 29 2013 fwang <fwang> 2.3.2-3.mga4
+ Revision: 430450
- more patch
- fix linkage
- add br
- use opengl
- rebuild for new jpeg-turbo

* Mon Jan 14 2013 umeabot <umeabot> 2.3.2-2.mga3
+ Revision: 385425
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 17 2012 shlomif <shlomif> 2.3.2-1.mga3
+ Revision: 319195
- Missing BR
- New version 2.3.2

* Sat Jun 16 2012 shlomif <shlomif> 2.3.1-1.mga3
+ Revision: 261041
- imported package virtualgl

